@@ -1,13 +1,10 @@
 # -*- coding: utf-8 -*-
 # ----------------------------------------------------------------------------
-# Copyright © Tom Hören
-
+# Copyright © Semi-ATE
 # Licensed under the terms of the MIT License
 # ----------------------------------------------------------------------------
-"""
-Python QtScreenCaster.
-"""
-from .QtScreenCast import *
+
+from QScreenCast.QScreenCast import *
 
 __version__ = "0.0.0"
-__version__='0.1.21'
+__version__='0.1.24'
